<div align=center>
  
  # DcWebhook v0.0.4
  
  **Simple Discord Webhook wrapper for Python.**
</div>

## +example:
![image](https://user-images.githubusercontent.com/81589649/180581102-2f71d337-a34f-4556-bce0-a16f26961d7f.png)    
**response**   
![image](https://user-images.githubusercontent.com/81589649/180581182-2a599c6e-5614-4903-bcb6-2c82046bc218.png)

## how to use
https://github.com/cookie0o/DcWebhook/wiki

## +Install:
**manually**
- Download project
- cd in the project dir with the console
- run: `pip install . --upgrade`
- your done!

**install with pip**
- run: `pip install DcWebhook`
- your done!

### +author(s) on github:
cookie0o